function []=example_remap(doRemap3d);
%object:    map a lon-lat field to gcmfaces
%input:     doRemap3d; if set to 1, then demo 3d case (involves
%               extrapolation, and takes a few minutes to compute)

gcmfaces_global;

fil=fullfile(myenv.gcmfaces_dir,filesep,'sample_input',filesep,'testcase_remap.mat');
if ~isempty(dir(fil));
    load(fil);
else;
    help gcmfaces_demo;
    warning('example_remap requires testcase_remap.mat that was not found ... abort');
    return;
end;

if isempty(whos('doRemap3d')); doRemap3d=0; end;

%%%%%%%%%%%%%%%%%
%load parameters:
%%%%%%%%%%%%%%%%%

nF=5;
fileFormat='compact';
dirGrid=fullfile(myenv.gcmfaces_dir,'..',filesep,'GRID',filesep);

mygrid=[]; grid_load(dirGrid,nF,fileFormat,0);

if myenv.verbose>0;
    gcmfaces_msg('===============================================');
    gcmfaces_msg(['*** entering example_remap that demonstrate ' ...
        'the use of gcmfaces_remap_2d and gcmfaces_remap_3d '],'');
end;

warning('off','MATLAB:dsearch:DeprecatedFunction');
warning('off','MATLAB:delaunay:DuplicateDataPoints');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%map lon-lat field to gcmfaces

if myenv.verbose>0;
    gcmfaces_msg('* map lon-lat field to gcmfaces');
end;

kk=20;%choice of output depth level
kkIn=max(find(depth<-mygrid.RC(kk)));% corresponding choice of input level

%without extrapolation (note: shallow regions are blank in FLD)
% ref_remap2d=FLD1(:,:,kkIn);
ref_remap2d=fld1(:,:,kk);
fld_remap2d=gcmfaces_remap_2d(lon,lat,FLD2(:,:,kkIn),3);
fld_remap2d_extrap=gcmfaces_remap_2d(lon,lat,FLD2(:,:,kkIn),3,mygrid.mskC(:,:,kk));

%extrapolate to fill 3D model domain (note: extrapolation is often a bad idea)
if doRemap3d;
    ref_remap3d=fld1(:,:,kk);
    fld_remap3d=gcmfaces_remap_3d(lon,lat,depth(kkIn+[-2:2]),FLD2(:,:,kkIn+[-2:2]));
    fld_repmat3d_kk=fld_remap3d(:,:,kk);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%quick display
cc=[0.4:0.05:1.1];
%
if myenv.verbose>0;
    gcmfaces_msg('* gcmfaces_remap_2d result (without extrapolation)');
end;
gcmfaces_sphere(fld_remap2d,cc,[],'N',1); title('gcmfaces_remap_2d result ');
if myenv.verbose>0;
    gcmfaces_msg('* gcmfaces_remap_2d result (with extrapolation)');
end;
gcmfaces_sphere(fld_remap2d_extrap,cc,[],'N',1); title('gcmfaces_remap_2d result (extrapolated)');
%
if doRemap3d;
    if myenv.verbose>0;
        gcmfaces_msg('* original field');
    end;
    gcmfaces_sphere(ref_remap2d,cc,[],'N',1); title('original field (slightly different level)');
    if myenv.verbose>0;
        gcmfaces_msg('* gcmfaces_remap_3d result (involves extrapolation)');
    end;
    gcmfaces_sphere(fld_repmat3d_kk,cc,[],'N',1); title('gcmfaces_remap_3d result');
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if myenv.verbose>0;
    gcmfaces_msg('*** leaving example_remap');
    gcmfaces_msg('===============================================');
end;




